module org.graalvm.nativeimage {
    requires transitive org.graalvm.word;
    exports com.oracle.svm.core.annotate;
    exports org.graalvm.nativeimage;
    exports org.graalvm.nativeimage.c;
    exports org.graalvm.nativeimage.c.constant;
    exports org.graalvm.nativeimage.c.function;
    exports org.graalvm.nativeimage.c.struct;
    exports org.graalvm.nativeimage.c.type;
    exports org.graalvm.nativeimage.hosted;
    exports org.graalvm.nativeimage.impl to com.oracle.svm.enterprise.truffle, com.oracle.svm.svm_enterprise, org.graalvm.extraimage.builder, org.graalvm.nativeimage.base, org.graalvm.nativeimage.builder, org.graalvm.nativeimage.configure, org.graalvm.nativeimage.foreign, org.graalvm.nativeimage.pointsto, org.graalvm.truffle.runtime.svm;
    exports org.graalvm.nativeimage.impl.clinit to org.graalvm.nativeimage.builder;
    uses org.graalvm.nativeimage.Platform;
    provides org.graalvm.nativeimage.Platform with org.graalvm.nativeimage.Platform.WINDOWS_AARCH64, org.graalvm.nativeimage.Platform.MACOS_AARCH64, org.graalvm.nativeimage.Platform.IOS_AMD64, org.graalvm.nativeimage.Platform.WINDOWS_AMD64, org.graalvm.nativeimage.Platform.LINUX_RISCV64, org.graalvm.nativeimage.Platform.IOS_AARCH64, org.graalvm.nativeimage.Platform.LINUX_AARCH64, org.graalvm.nativeimage.Platform.ANDROID_AARCH64, org.graalvm.nativeimage.Platform.MACOS_AMD64, org.graalvm.nativeimage.Platform.LINUX_AMD64;
}
